[Asterisk-code-review] spelling: right (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:16:27 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17172 )


Change subject: spelling: right
......................................................................

spelling: right

Change-Id: Ife7aff07ddce3128472296c9a72a2b55a5052545
---
M apps/app_minivm.c
M apps/app_voicemail.c
M channels/chan_skinny.c
M codecs/ilbc/rfc3951.txt
M configs/samples/minivm.conf.sample
M contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
M include/asterisk/app.h
M main/pbx.c
M tests/test_voicemail_api.c
9 files changed, 75 insertions(+), 75 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/72/17172/1

diff --git a/apps/app_minivm.c b/apps/app_minivm.c
index 0e5ee2e..c89f57b 100644
--- a/apps/app_minivm.c
+++ b/apps/app_minivm.c
@@ -2011,7 +2011,7 @@
 			S_COR(ast_channel_caller(chan)->id.number.valid, ast_channel_caller(chan)->id.number.str, NULL),
 			"Unknown");
 		snprintf(logbuf, sizeof(logbuf),
-			/* "Mailbox:domain:macrocontext:exten:priority:callerchan:callerid:origdate:origtime:duration:durationstatus:accountcode" */
+			/* "Mailbox:domain:macrocontext:exten:priority:callerchan:callerid:origdate:orightime:duration:durationstatus:accountcode" */
 			"%s:%s:%s:%s:%d:%s:%s:%s:%s:%d:%s:%s\n",
 			username,
 			ast_channel_context(chan),
diff --git a/apps/app_voicemail.c b/apps/app_voicemail.c
index dc0520d..3f2e904 100644
--- a/apps/app_voicemail.c
+++ b/apps/app_voicemail.c
@@ -2390,7 +2390,7 @@
 		fprintf(text_file_ptr, "context=%s\n", S_OR(buf, ""));
 	}
 	if (get_header_by_tag(header_content, "X-Asterisk-VM-Orig-time:", buf, sizeof(buf))) {
-		fprintf(text_file_ptr, "origtime=%s\n", S_OR(buf, ""));
+		fprintf(text_file_ptr, "orightime=%s\n", S_OR(buf, ""));
 	}
 	if (get_header_by_tag(header_content, "X-Asterisk-VM-Duration:", buf, sizeof(buf))) {
 		fprintf(text_file_ptr, "duration=%s\n", S_OR(buf, ""));
@@ -4246,7 +4246,7 @@
 
 	snprintf(msgnums, sizeof(msgnums), "%d", smsg);
 	snprintf(msgnumd, sizeof(msgnumd), "%d", dmsg);
-	snprintf(sql, sizeof(sql), "INSERT INTO %s (dir, msgnum, msg_id, context, macrocontext, callerid, origtime, duration, recording, flag, mailboxuser, mailboxcontext) SELECT ?,?,?,context,macrocontext,callerid,origtime,duration,recording,flag,?,? FROM %s WHERE dir=? AND msgnum=?", odbc_table, odbc_table);
+	snprintf(sql, sizeof(sql), "INSERT INTO %s (dir, msgnum, msg_id, context, macrocontext, callerid, orightime, duration, recording, flag, mailboxuser, mailboxcontext) SELECT ?,?,?,context,macrocontext,callerid,orightime,duration,recording,flag,?,? FROM %s WHERE dir=? AND msgnum=?", odbc_table, odbc_table);
 	stmt = ast_odbc_prepare_and_execute(obj, generic_prepare, &gps);
 	if (!stmt)
 		ast_log(AST_LOG_WARNING, "SQL Execute error!\n[%s] (You probably don't have MySQL 4.1 or later installed)\n\n", sql);
@@ -4267,7 +4267,7 @@
 	const char *context;
 	const char *macrocontext;
 	const char *callerid;
-	const char *origtime;
+	const char *orightime;
 	const char *duration;
 	const char *mailboxuser;
 	const char *mailboxcontext;
@@ -4294,7 +4294,7 @@
 	SQLBindParameter(stmt, 4, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->context), 0, (void *) data->context, 0, NULL);
 	SQLBindParameter(stmt, 5, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->macrocontext), 0, (void *) data->macrocontext, 0, NULL);
 	SQLBindParameter(stmt, 6, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->callerid), 0, (void *) data->callerid, 0, NULL);
-	SQLBindParameter(stmt, 7, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->origtime), 0, (void *) data->origtime, 0, NULL);
+	SQLBindParameter(stmt, 7, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->orightime), 0, (void *) data->orightime, 0, NULL);
 	SQLBindParameter(stmt, 8, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->duration), 0, (void *) data->duration, 0, NULL);
 	SQLBindParameter(stmt, 9, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->mailboxuser), 0, (void *) data->mailboxuser, 0, NULL);
 	SQLBindParameter(stmt, 10, SQL_PARAM_INPUT, SQL_C_CHAR, SQL_CHAR, strlen(data->mailboxcontext), 0, (void *) data->mailboxcontext, 0, NULL);
@@ -4342,7 +4342,7 @@
 	struct ast_config *cfg = NULL;
 	struct odbc_obj *obj;
 	struct insert_data idata = { .sql = sql, .msgnums = msgnums, .dir = dir, .mailboxuser = mailboxuser, .mailboxcontext = mailboxcontext,
-		.context = "", .macrocontext = "", .callerid = "", .origtime = "", .duration = "", .category = "", .flag = "", .msg_id = "" };
+		.context = "", .macrocontext = "", .callerid = "", .orightime = "", .duration = "", .category = "", .flag = "", .msg_id = "" };
 	struct ast_flags config_flags = { CONFIG_FLAG_NOCACHE };
 
 	delete_file(dir, msgnum);
@@ -4384,8 +4384,8 @@
 			if (!(idata.callerid = ast_variable_retrieve(cfg, "message", "callerid"))) {
 				idata.callerid = "";
 			}
-			if (!(idata.origtime = ast_variable_retrieve(cfg, "message", "origtime"))) {
-				idata.origtime = "";
+			if (!(idata.orightime = ast_variable_retrieve(cfg, "message", "orightime"))) {
+				idata.orightime = "";
 			}
 			if (!(idata.duration = ast_variable_retrieve(cfg, "message", "duration"))) {
 				idata.duration = "";
@@ -4416,12 +4416,12 @@
 		idata.datalen = idata.indlen = fdlen;
 
 		if (!ast_strlen_zero(idata.category))
-			snprintf(sql, sizeof(sql), "INSERT INTO %s (dir,msgnum,recording,context,macrocontext,callerid,origtime,duration,mailboxuser,mailboxcontext,flag,msg_id,category) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)", odbc_table);
+			snprintf(sql, sizeof(sql), "INSERT INTO %s (dir,msgnum,recording,context,macrocontext,callerid,orightime,duration,mailboxuser,mailboxcontext,flag,msg_id,category) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?)", odbc_table);
 		else
-			snprintf(sql, sizeof(sql), "INSERT INTO %s (dir,msgnum,recording,context,macrocontext,callerid,origtime,duration,mailboxuser,mailboxcontext,flag,msg_id) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)", odbc_table);
+			snprintf(sql, sizeof(sql), "INSERT INTO %s (dir,msgnum,recording,context,macrocontext,callerid,orightime,duration,mailboxuser,mailboxcontext,flag,msg_id) VALUES (?,?,?,?,?,?,?,?,?,?,?,?)", odbc_table);
 
-		if (ast_strlen_zero(idata.origtime)) {
-			idata.origtime = "0";
+		if (ast_strlen_zero(idata.orightime)) {
+			idata.orightime = "0";
 		}
 
 		if (ast_strlen_zero(idata.duration)) {
@@ -4704,7 +4704,7 @@
 	struct ast_variable *tmp, *var = NULL;
 	const char *origmailbox = "", *context = "", *macrocontext = "", *exten = "";
 	const char *priority = "", *callerchan = "", *callerid = "", *origdate = "";
-	const char *origtime = "", *category = "", *duration = "";
+	const char *orightime = "", *category = "", *duration = "";
 
 	ast_filecopy(frompath, topath, NULL);
 	snprintf(frompath2, sizeof(frompath2), "%s.txt", frompath);
@@ -4730,15 +4730,15 @@
 				callerid = tmp->value;
 			} else if (!strcasecmp(tmp->name, "origdate")) {
 				origdate = tmp->value;
-			} else if (!strcasecmp(tmp->name, "origtime")) {
-				origtime = tmp->value;
+			} else if (!strcasecmp(tmp->name, "orightime")) {
+				orightime = tmp->value;
 			} else if (!strcasecmp(tmp->name, "category")) {
 				category = tmp->value;
 			} else if (!strcasecmp(tmp->name, "duration")) {
 				duration = tmp->value;
 			}
 		}
-		ast_store_realtime("voicemail_data", "filename", topath, "origmailbox", origmailbox, "context", context, "macrocontext", macrocontext, "exten", exten, "priority", priority, "callerchan", callerchan, "callerid", callerid, "origdate", origdate, "origtime", origtime, "category", category, "duration", duration, SENTINEL);
+		ast_store_realtime("voicemail_data", "filename", topath, "origmailbox", origmailbox, "context", context, "macrocontext", macrocontext, "exten", exten, "priority", priority, "callerchan", callerchan, "callerid", callerid, "origdate", origdate, "orightime", orightime, "category", category, "duration", duration, SENTINEL);
 	}
 	copy(frompath2, topath2);
 	ast_variables_destroy(var);
@@ -4905,7 +4905,7 @@
 	char num[12];
 	char fromdir[256], fromfile[256];
 	struct ast_config *msg_cfg;
-	const char *origcallerid, *origtime;
+	const char *origcallerid, *orightime;
 	char origcidname[80], origcidnum[80], origdate[80];
 	int inttime;
 	struct ast_flags config_flags = { CONFIG_FLAG_NOCACHE };
@@ -4943,7 +4943,7 @@
 		pbx_builtin_setvar_helper(ast, "ORIG_VM_CIDNUM", origcidnum);
 	}
 
-	if ((origtime = ast_variable_retrieve(msg_cfg, "message", "origtime")) && sscanf(origtime, "%30d", &inttime) == 1) {
+	if ((orightime = ast_variable_retrieve(msg_cfg, "message", "orightime")) && sscanf(orightime, "%30d", &inttime) == 1) {
 		struct timeval tv = { inttime, };
 		struct ast_tm tm;
 		ast_localtime(&tv, &tm, NULL);
@@ -5344,7 +5344,7 @@
 
 				/* You might be tempted to do origdate, except that a) it's in the wrong
 				 * format, and b) it's missing for IMAP recordings. */
-				if ((v = ast_variable_retrieve(msg_cfg, "message", "origtime")) && sscanf(v, "%30d", &inttime) == 1) {
+				if ((v = ast_variable_retrieve(msg_cfg, "message", "orightime")) && sscanf(v, "%30d", &inttime) == 1) {
 					struct timeval tv = { inttime, };
 					struct ast_tm tm;
 					ast_localtime(&tv, &tm, NULL);
@@ -6424,7 +6424,7 @@
 			"callerchan=%s\n"
 			"callerid=%s\n"
 			"origdate=%s\n"
-			"origtime=%ld\n"
+			"orightime=%ld\n"
 			"category=%s\n"
 			"msg_id=%s\n"
 			"flag=\n" /* flags not supported in copy from file yet */
@@ -6579,7 +6579,7 @@
 				"callerchan", S_OR(recdata->call_callerchan, "Unknown"),
 				"callerid", S_OR(recdata->call_callerid, "Unknown"),
 				"origdate", date,
-				"origtime", time(NULL),
+				"orightime", time(NULL),
 				"category", S_OR(category, ""),
 				"filename", tmptxtfile,
 				"duration", duration,
@@ -6627,7 +6627,7 @@
 	int greeting_only = 0;
 	char tmpdur[16];
 	char priority[16];
-	char origtime[16];
+	char orightime[16];
 	char dir[PATH_MAX];
 	char tmpdir[PATH_MAX];
 	char fn[PATH_MAX];
@@ -6969,7 +6969,7 @@
 		/* Store information in real-time storage */
 		if (ast_check_realtime("voicemail_data")) {
 			snprintf(priority, sizeof(priority), "%d", ast_channel_priority(chan));
-			snprintf(origtime, sizeof(origtime), "%ld", (long) time(NULL));
+			snprintf(orightime, sizeof(orightime), "%ld", (long) time(NULL));
 			get_date(date, sizeof(date));
 			ast_callerid_merge(callerid, sizeof(callerid),
 				S_COR(ast_channel_caller(chan)->id.name.valid, ast_channel_caller(chan)->id.name.str, NULL),
@@ -6984,7 +6984,7 @@
 				"callerchan", ast_channel_name(chan),
 				"callerid", callerid,
 				"origdate", date,
-				"origtime", origtime,
+				"orightime", orightime,
 				"category", S_OR(category, ""),
 				"filename", tmptxtfile,
 				SENTINEL);
@@ -7013,7 +7013,7 @@
 				"callerchan=%s\n"
 				"callerid=%s\n"
 				"origdate=%s\n"
-				"origtime=%ld\n"
+				"orightime=%ld\n"
 				"category=%s\n"
 				"msg_id=%s\n",
 				ext,
@@ -8648,14 +8648,14 @@
 	return res;
 }
 
-static int play_message_datetime(struct ast_channel *chan, struct ast_vm_user *vmu, const char *origtime, const char *filename)
+static int play_message_datetime(struct ast_channel *chan, struct ast_vm_user *vmu, const char *orightime, const char *filename)
 {
 	int res = 0;
 	struct vm_zone *the_zone = NULL;
 	time_t t;
 
-	if (ast_get_time_t(origtime, &t, 0, NULL)) {
-		ast_log(AST_LOG_WARNING, "Couldn't find origtime in %s\n", filename);
+	if (ast_get_time_t(orightime, &t, 0, NULL)) {
+		ast_log(AST_LOG_WARNING, "Couldn't find orightime in %s\n", filename);
 		return 0;
 	}
 
@@ -8857,7 +8857,7 @@
 {
 	int res = 0;
 	char filename[PATH_MAX], *cid;
-	const char *origtime, *context, *category, *duration, *flag;
+	const char *orightime, *context, *category, *duration, *flag;
 	struct ast_config *msg_cfg;
 	struct ast_flags config_flags = { CONFIG_FLAG_NOCACHE };
 
@@ -8962,8 +8962,8 @@
 		return 0;
 	}
 
-	if (!(origtime = ast_variable_retrieve(msg_cfg, "message", "origtime"))) {
-		ast_log(AST_LOG_WARNING, "No origtime?!\n");
+	if (!(orightime = ast_variable_retrieve(msg_cfg, "message", "orightime"))) {
+		ast_log(AST_LOG_WARNING, "No orightime?!\n");
 		DISPOSE(vms->curdir, vms->curmsg);
 		ast_config_destroy(msg_cfg);
 		return 0;
@@ -8980,7 +8980,7 @@
 		res = play_message_category(chan, category);
 	}
 	if ((!res) && (ast_test_flag(vmu, VM_ENVELOPE))) {
-		res = play_message_datetime(chan, vmu, origtime, filename);
+		res = play_message_datetime(chan, vmu, orightime, filename);
 	}
 	if ((!res) && (ast_test_flag(vmu, VM_SAYCID))) {
 		res = play_message_callerid(chan, vms, cid, context, 0, 0);
@@ -15320,7 +15320,7 @@
 	int res = 0;
 	char filename[PATH_MAX];
 	struct ast_config *msg_cfg = NULL;
-	const char *origtime, *context;
+	const char *orightime, *context;
 	char *name, *num;
 	int retries = 0;
 	char *cid;
@@ -15340,7 +15340,7 @@
 		return 0;
 	}
 
-	if (!(origtime = ast_variable_retrieve(msg_cfg, "message", "origtime"))) {
+	if (!(orightime = ast_variable_retrieve(msg_cfg, "message", "orightime"))) {
 		ast_config_destroy(msg_cfg);
 		return 0;
 	}
@@ -15353,7 +15353,7 @@
 	switch (option) {
 	case 3: /* Play message envelope */
 		if (!res) {
-			res = play_message_datetime(chan, vmu, origtime, filename);
+			res = play_message_datetime(chan, vmu, orightime, filename);
 		}
 		if (!res) {
 			res = play_message_callerid(chan, vms, cid, context, 0, 1);
@@ -15887,8 +15887,8 @@
 		if ((value = ast_variable_retrieve(msg_cfg, "message", "origdate"))) {
 			ast_string_field_set(msg_snapshot, origdate, value);
 		}
-		if ((value = ast_variable_retrieve(msg_cfg, "message", "origtime"))) {
-			ast_string_field_set(msg_snapshot, origtime, value);
+		if ((value = ast_variable_retrieve(msg_cfg, "message", "orightime"))) {
+			ast_string_field_set(msg_snapshot, orightime, value);
 		}
 		if ((value = ast_variable_retrieve(msg_cfg, "message", "duration"))) {
 			ast_string_field_set(msg_snapshot, duration, value);
@@ -15912,7 +15912,7 @@
 			break;
 		case AST_VM_SNAPSHOT_SORT_BY_TIME:
 			AST_LIST_TRAVERSE_SAFE_BEGIN(&mailbox_snapshot->snapshots[snapshot_index], msg_snapshot_tmp, msg) {
-				int val = strcmp(msg_snapshot->origtime, msg_snapshot_tmp->origtime);
+				int val = strcmp(msg_snapshot->orightime, msg_snapshot_tmp->orightime);
 				if (descending && val >= 0) {
 					AST_LIST_INSERT_BEFORE_CURRENT(msg_snapshot, msg);
 					inserted = 1;
diff --git a/codecs/ilbc/rfc3951.txt b/codecs/ilbc/rfc3951.txt
index 7883f3a..de8a65b 100644
--- a/codecs/ilbc/rfc3951.txt
+++ b/codecs/ilbc/rfc3951.txt
@@ -10715,7 +10715,7 @@
 
    Alan Duric
    Telio AS
-   Stoperigt. 2
+   Stoperight. 2
    Oslo, N-0250
    Norway
 
diff --git a/configs/samples/minivm.conf.sample b/configs/samples/minivm.conf.sample
index b7f3810..9291aaa 100644
--- a/configs/samples/minivm.conf.sample
+++ b/configs/samples/minivm.conf.sample
@@ -34,7 +34,7 @@
 ;
 ;Turn on logfile with the following syntax. One line per voicemail received
 ;with minivmRecord()
-; Mailbox:domain:macrocontext:exten:priority:callerchan:callerid:origdate:origtime:duration:durationstatus:accountcode
+; Mailbox:domain:macrocontext:exten:priority:callerchan:callerid:origdate:orightime:duration:durationstatus:accountcode
 ;logfile=/var/log/asterisk/minivm.log
 ; Who the e-mail notification should appear to come from
 serveremail=asterisk
diff --git a/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py b/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
index 3dc4d47..aebcaaa 100644
--- a/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
+++ b/contrib/ast-db-manage/voicemail/versions/a2e9769475e_create_tables.py
@@ -40,7 +40,7 @@
         sa.Column('context', sa.String(80)),
         sa.Column('macrocontext', sa.String(80)),
         sa.Column('callerid', sa.String(80)),
-        sa.Column('origtime', sa.Integer),
+        sa.Column('orightime', sa.Integer),
         sa.Column('duration', sa.Integer),
         sa.Column('recording', sa.LargeBinary),
         sa.Column('flag', sa.String(30)),
diff --git a/include/asterisk/app.h b/include/asterisk/app.h
index 560f852..fa5543c 100644
--- a/include/asterisk/app.h
+++ b/include/asterisk/app.h
@@ -321,7 +321,7 @@
 		AST_STRING_FIELD(callerchan);
 		AST_STRING_FIELD(exten);
 		AST_STRING_FIELD(origdate);
-		AST_STRING_FIELD(origtime);
+		AST_STRING_FIELD(orightime);
 		AST_STRING_FIELD(duration);
 		AST_STRING_FIELD(folder_name);
 		AST_STRING_FIELD(flag);
diff --git a/main/pbx.c b/main/pbx.c
index cfc6059..e64872b 100644
--- a/main/pbx.c
+++ b/main/pbx.c
@@ -4891,7 +4891,7 @@
 }
 
 /*!
- * \note This function locks contexts list by &conlist, search for the rigt context
+ * \note This function locks contexts list by &conlist, search for the right context
  * structure, leave context list locked and call ast_context_remove_switch2
  * which removes switch, unlock contexts list and return ...
  */
diff --git a/tests/test_voicemail_api.c b/tests/test_voicemail_api.c
index faf99bc..7767f7f 100644
--- a/tests/test_voicemail_api.c
+++ b/tests/test_voicemail_api.c
@@ -158,7 +158,7 @@
 			VM_API_STRING_FIELD_VERIFY((expected)->callerchan, msg->callerchan); \
 			VM_API_STRING_FIELD_VERIFY((expected)->exten, msg->exten); \
 			VM_API_STRING_FIELD_VERIFY((expected)->origdate, msg->origdate); \
-			VM_API_STRING_FIELD_VERIFY((expected)->origtime, msg->origtime); \
+			VM_API_STRING_FIELD_VERIFY((expected)->orightime, msg->orightime); \
 			VM_API_STRING_FIELD_VERIFY((expected)->duration, msg->duration); \
 			VM_API_STRING_FIELD_VERIFY((expected)->folder_name, msg->folder_name); \
 			VM_API_STRING_FIELD_VERIFY((expected)->flag, msg->flag); \
@@ -497,7 +497,7 @@
 		"callerchan=%s\n"
 		"callerid=%s\n"
 		"origdate=%s\n"
-		"origtime=%s\n"
+		"orightime=%s\n"
 		"category=%s\n"
 		"msg_id=%s\n"
 		"flag=%s\n"
@@ -511,7 +511,7 @@
 		snapshot->callerchan,
 		snapshot->callerid,
 		snapshot->origdate,
-		snapshot->origtime,
+		snapshot->orightime,
 		"",
 		snapshot->msg_id,
 		snapshot->flag,
@@ -666,7 +666,7 @@
 	/* Set the basic properties on each */
 	ast_string_field_set(msg_one, callerchan, "SIP/2000-00000000");
 	ast_string_field_set(msg_one, origdate, "Mon Mar 19 04:14:21 PM UTC 2012");
-	ast_string_field_set(msg_one, origtime, "1332173661");
+	ast_string_field_set(msg_one, orightime, "1332173661");
 	ast_string_field_set(msg_one, duration, "8");
 	ast_string_field_set(msg_one, folder_name, "Old");
 	msg_one->msg_number = 0;
@@ -674,7 +674,7 @@
 
 	ast_string_field_set(msg_two, callerchan, "SIP/8000-00000001");
 	ast_string_field_set(msg_two, origdate, "Mon Mar 19 06:16:13 PM UTC 2012");
-	ast_string_field_set(msg_two, origtime, "1332180973");
+	ast_string_field_set(msg_two, orightime, "1332180973");
 	ast_string_field_set(msg_two, duration, "24");
 	ast_string_field_set(msg_two, folder_name, "INBOX");
 	msg_two->msg_number = 0;
@@ -682,7 +682,7 @@
 
 	ast_string_field_set(msg_three, callerchan, "IAX/2000-000000a3");
 	ast_string_field_set(msg_three, origdate, "Thu Mar 22 23:13:03 PM UTC 2012");
-	ast_string_field_set(msg_three, origtime, "1332181251");
+	ast_string_field_set(msg_three, orightime, "1332181251");
 	ast_string_field_set(msg_three, duration, "25");
 	ast_string_field_set(msg_three, folder_name, "INBOX");
 	msg_three->msg_number = 0;
@@ -690,7 +690,7 @@
 
 	ast_string_field_set(msg_four, callerchan, "DAHDI/3000-00000010");
 	ast_string_field_set(msg_four, origdate, "Fri Mar 23 03:01:03 AM UTC 2012");
-	ast_string_field_set(msg_four, origtime, "1332181362");
+	ast_string_field_set(msg_four, orightime, "1332181362");
 	ast_string_field_set(msg_four, duration, "13");
 	ast_string_field_set(msg_four, folder_name, "INBOX");
 	msg_three->msg_number = 1;
@@ -750,7 +750,7 @@
 					ast_string_field_set(test_snapshots[i], callerchan, msg->callerchan);
 					ast_string_field_set(test_snapshots[i], exten, msg->exten);
 					ast_string_field_set(test_snapshots[i], origdate, msg->origdate);
-					ast_string_field_set(test_snapshots[i], origtime, msg->origtime);
+					ast_string_field_set(test_snapshots[i], orightime, msg->orightime);
 					ast_string_field_set(test_snapshots[i], duration, msg->duration);
 					ast_string_field_set(test_snapshots[i], folder_name, msg->folder_name);
 					ast_string_field_set(test_snapshots[i], flag, msg->flag);

diff --git a/channels/chan_skinny.c b/channels/chan_skinny.c
index 5b95026..66a6f2b 100644
--- a/channels/chan_skinny.c
+++ b/channels/chan_skinny.c
@@ -1411,8 +1411,8 @@
 	int cfwd_sched;
 	int dialType;
 	int getforward;
-	char *origtonum;
-	char *origtoname;
+	char *orightonum;
+	char *orightoname;
 
 	AST_LIST_ENTRY(skinny_subchannel) list;
 	struct skinny_subchannel *related;
@@ -2466,7 +2466,7 @@
 
 //static void transmit_callinfo(struct skinny_subchannel *sub)
 static void transmit_callinfo(struct skinny_device *d, int instance, int callid,
-	char *fromname, char *fromnum, char *toname, char *tonum, int calldirection, char *origtonum, char *origtoname)
+	char *fromname, char *fromnum, char *toname, char *tonum, int calldirection, char *orightonum, char *orightoname)
 {
 	struct skinny_req *req;
 
@@ -2477,24 +2477,24 @@
 	ast_copy_string(req->data.callinfo.callingParty, fromnum, sizeof(req->data.callinfo.callingParty));
 	ast_copy_string(req->data.callinfo.calledPartyName, toname, sizeof(req->data.callinfo.calledPartyName));
 	ast_copy_string(req->data.callinfo.calledParty, tonum, sizeof(req->data.callinfo.calledParty));
-	if (origtoname) {
-		ast_copy_string(req->data.callinfo.originalCalledPartyName, origtoname, sizeof(req->data.callinfo.originalCalledPartyName));
+	if (orightoname) {
+		ast_copy_string(req->data.callinfo.originalCalledPartyName, orightoname, sizeof(req->data.callinfo.originalCalledPartyName));
 	}
-	if (origtonum) {
-		ast_copy_string(req->data.callinfo.originalCalledParty, origtonum, sizeof(req->data.callinfo.originalCalledParty));
+	if (orightonum) {
+		ast_copy_string(req->data.callinfo.originalCalledParty, orightonum, sizeof(req->data.callinfo.originalCalledParty));
 	}
 
 	req->data.callinfo.instance = htolel(instance);
 	req->data.callinfo.reference = htolel(callid);
 	req->data.callinfo.type = htolel(calldirection);
 
-	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting CALL_INFO_MESSAGE to %s, to %s(%s) from %s(%s), origto %s(%s) (dir=%d) on %s(%d)\n",
-		d->name, toname, tonum, fromname, fromnum, origtoname, origtonum, calldirection, d->name, instance);
+	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting CALL_INFO_MESSAGE to %s, to %s(%s) from %s(%s), orighto %s(%s) (dir=%d) on %s(%d)\n",
+		d->name, toname, tonum, fromname, fromnum, orightoname, orightonum, calldirection, d->name, instance);
 	transmit_response(d, req);
 }
 
 static void transmit_callinfo_variable(struct skinny_device *d, int instance, int callreference,
-	char *fromname, char *fromnum, char *toname, char *tonum, int calldirection, char *origtonum, char *origtoname)
+	char *fromname, char *fromnum, char *toname, char *tonum, int calldirection, char *orightonum, char *orightoname)
 {
 	struct skinny_req *req;
 	char *strptr;
@@ -2519,7 +2519,7 @@
 	thestrings[1] = "";                     /* Appears to be origfrom */
 	if (calldirection == SKINNY_OUTGOING) {
 		thestrings[2] = tonum;
-		thestrings[3] = origtonum;
+		thestrings[3] = orightonum;
 	} else {
 		thestrings[2] = "";
 		thestrings[3] = "";
@@ -2532,7 +2532,7 @@
 	thestrings[8] = "";
 	thestrings[9] = fromname;
 	thestrings[10] = toname;
-	thestrings[11] = origtoname;
+	thestrings[11] = orightoname;
 	thestrings[12] = "";
 
 	strptr = req->data.callinfomessagevariable.calldetails;
@@ -2551,8 +2551,8 @@
 
 	req->len = req->len - (callinfostrleft & ~0x3);
 
-	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting CALL_INFO_MESSAGE_VARIABLE to %s, to %s(%s) from %s(%s), origto %s(%s) (dir=%d) on %s(%d)\n",
-		d->name, toname, tonum, fromname, fromnum, origtoname, origtonum, calldirection, d->name, instance);
+	SKINNY_DEBUG(DEBUG_PACKET, 3, "Transmitting CALL_INFO_MESSAGE_VARIABLE to %s, to %s(%s) from %s(%s), orighto %s(%s) (dir=%d) on %s(%d)\n",
+		d->name, toname, tonum, fromname, fromnum, orightoname, orightonum, calldirection, d->name, instance);
 	transmit_response(d, req);
 }
 
@@ -2597,9 +2597,9 @@
 	}
 
 	if (d->protocolversion < 17) {
-		transmit_callinfo(d, l->instance, sub->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->origtonum, sub->origtoname);
+		transmit_callinfo(d, l->instance, sub->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->orightonum, sub->orightoname);
 	} else {
-		transmit_callinfo_variable(d, l->instance, sub->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->origtonum, sub->origtoname);
+		transmit_callinfo_variable(d, l->instance, sub->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->orightonum, sub->orightoname);
 	}
 }
 
@@ -2644,9 +2644,9 @@
 	}
 
 	if (d->protocolversion < 17) {
-		transmit_callinfo(subline->line->device, subline->line->instance, subline->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->origtonum, sub->origtoname);
+		transmit_callinfo(subline->line->device, subline->line->instance, subline->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->orightonum, sub->orightoname);
 	} else {
-		transmit_callinfo_variable(subline->line->device, subline->line->instance, subline->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->origtonum, sub->origtoname);
+		transmit_callinfo_variable(subline->line->device, subline->line->instance, subline->callid, fromname, fromnum, toname, tonum, sub->calldirection, sub->orightonum, sub->orightoname);
 	}
 }
 
@@ -3535,11 +3535,11 @@
 		return;
 	}
 
-	if (sub->calldirection == SKINNY_OUTGOING && !sub->origtonum) {
-		/* Do not set origtonum before here or origtoname won't be set */
-		sub->origtonum = ast_strdup(sub->exten);
+	if (sub->calldirection == SKINNY_OUTGOING && !sub->orightonum) {
+		/* Do not set orightonum before here or orightoname won't be set */
+		sub->orightonum = ast_strdup(sub->exten);
 		if (ast_channel_connected(c)->id.name.valid) {
-			sub->origtoname = ast_strdup(ast_channel_connected(c)->id.name.str);
+			sub->orightoname = ast_strdup(ast_channel_connected(c)->id.name.str);
 		}
 	}
 
@@ -5003,8 +5003,8 @@
 	skinny_set_owner(sub, NULL);
 	ast_channel_tech_pvt_set(ast, NULL);
 	destroy_rtp(sub);
-	ast_free(sub->origtonum);
-	ast_free(sub->origtoname);
+	ast_free(sub->orightonum);
+	ast_free(sub->orightoname);
 	ast_free(sub);
 	ast_module_unref(ast_module_info->self);
 	return 0;
-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17172
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: Ife7aff07ddce3128472296c9a72a2b55a5052545
Gerrit-Change-Number: 17172
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/8e6e8fb0/attachment-0001.html>


More information about the asterisk-code-review mailing list